@@ -321,6 +321,16 @@ namespace Model
     template<typename ConnectionTrackingSpecificationT = ConnectionTrackingSpecification>
     LaunchTemplateInstanceNetworkInterfaceSpecification& WithConnectionTrackingSpecification(ConnectionTrackingSpecificationT&& value) { SetConnectionTrackingSpecification(std::forward<ConnectionTrackingSpecificationT>(value)); return *this;}
     ///@}
+
+    ///@{
+    /**
+     * <p>The number of ENA queues created with the instance.</p>
+     */
+    inline int GetEnaQueueCount() const { return m_enaQueueCount; }
+    inline bool EnaQueueCountHasBeenSet() const { return m_enaQueueCountHasBeenSet; }
+    inline void SetEnaQueueCount(int value) { m_enaQueueCountHasBeenSet = true; m_enaQueueCount = value; }
+    inline LaunchTemplateInstanceNetworkInterfaceSpecification& WithEnaQueueCount(int value) { SetEnaQueueCount(value); return *this;}
+    ///@}
   private:
 
     bool m_associateCarrierIpAddress{false};
@@ -388,6 +398,9 @@ namespace Model
 
     ConnectionTrackingSpecification m_connectionTrackingSpecification;
     bool m_connectionTrackingSpecificationHasBeenSet = false;
+
+    int m_enaQueueCount{0};
+    bool m_enaQueueCountHasBeenSet = false;
   };
 
 } // namespace Model
