@@ -72,6 +72,19 @@ namespace Model
     Volume& WithOutpostArn(OutpostArnT&& value) { SetOutpostArn(std::forward<OutpostArnT>(value)); return *this;}
     ///@}
 
+    ///@{
+    /**
+     * <p>The ID of the source volume from which the volume copy was created. Only for
+     * volume copies.</p>
+     */
+    inline const Aws::String& GetSourceVolumeId() const { return m_sourceVolumeId; }
+    inline bool SourceVolumeIdHasBeenSet() const { return m_sourceVolumeIdHasBeenSet; }
+    template<typename SourceVolumeIdT = Aws::String>
+    void SetSourceVolumeId(SourceVolumeIdT&& value) { m_sourceVolumeIdHasBeenSet = true; m_sourceVolumeId = std::forward<SourceVolumeIdT>(value); }
+    template<typename SourceVolumeIdT = Aws::String>
+    Volume& WithSourceVolumeId(SourceVolumeIdT&& value) { SetSourceVolumeId(std::forward<SourceVolumeIdT>(value)); return *this;}
+    ///@}
+
     ///@{
     /**
      * <p>The number of I/O operations per second (IOPS). For <code>gp3</code>,
@@ -298,6 +311,9 @@ namespace Model
     Aws::String m_outpostArn;
     bool m_outpostArnHasBeenSet = false;
 
+    Aws::String m_sourceVolumeId;
+    bool m_sourceVolumeIdHasBeenSet = false;
+
     int m_iops{0};
     bool m_iopsHasBeenSet = false;
 
